@@ -1,4 +1,4 @@
-# Copyright (C) 2007 by Barry A. Warsaw
+# Copyright (C) 2007-2008 by Barry A. Warsaw
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public License
@@ -229,7 +229,8 @@ class Lock:
                 raise TimeOutError('Could not acquire the lock')
             # Okay, we haven't timed out, but we didn't get the lock.  Let's
             # find if the lock lifetime has expired.
-            if datetime.datetime.now() > self._releasetime + CLOCK_SLOP:
+            if (self._releasetime != -1 and
+                datetime.datetime.now() > self._releasetime + CLOCK_SLOP):
                 # Yes, so break the lock.
                 self._break()
                 log.error('lifetime has expired, breaking')
